==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/my_publishing.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "my_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_publish_library'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($publish_library[0])) {
				foreach($publish_library as $key => $i):
				?>
				 <tr>
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<a href="g_library.php?group_id=<?php echo $i['group_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>"></a>
						<?
						}
						?>
						<a href="g_library.php?group_id=<?php echo $i['group_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
						<span class="txt_footer"><?php echo dots('120', $i['library_synopsis']);?></span><br />
					</td>
					<td align="right" valign="top">
						<span class="txt_footer"><?php echo $i['library_total_views'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="3">
						<?php echo $lang['err_no_library'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_publish_forum'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($publish_forum[0]['subject_id'])) {
				foreach($publish_forum as $key => $i):
				?>
				 <tr>
					<td>
						<a href="g_forum_subject.php?group_id=<?php echo $i['group_id'];?>&amp;topic_id=<?php echo $i['topic_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<span class="txt_footer"><?php echo dots('120', $i['subject_body']);?></span><br />
					</td>
					<td align="right" valign="top">
						<span class="txt_footer"><?php echo $i['total_replies'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_forum'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_publish_blog_item'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blogs[0])) {
				foreach($blogs as $key => $i):
				?>
				 <tr>
					<td valign="top">
						<a href="my_blog.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['blog_synopsis'];?></span><br />
					</td>
					<td align="right" valign="top" nowrap>
						<span class="txt_footer"><?php echo $i['blog_create_datetime'];?></span><br />
						<span class="txt_footer"><?php echo $i['blog_total_views'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_blogs'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>


		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_poll_participation'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($poll_participation[0])) {
				foreach($poll_participation as $key => $i):
				?>
				 <tr>
					<td valign="top">
						<?php echo $i['poll_question'];?><br />
						<span class="txt_footer"><?php echo $i['option_body'];?></span><br />
					</td>
					<td align="right" valign="top">
						<span class="txt_footer"><?php echo $i['answer_create_datetime'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_poll_participation'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_publish_shouts'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($publish_shouts[0])) {
				foreach($publish_shouts as $key => $i):
				?>
			    <tr valign="top">
					<td>
						<?php echo $i['shoutbox_create_datetime'];?>: <?php echo $i['shoutbox_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_shouts'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>
	</tr>
</table>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/my_publishing.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "my_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_publish_library'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($publish_library)) {
				foreach($publish_library as $key => $i):
				?>
				 <tr>
					<td>
						<a href="g_library.php?group_id=<?php echo $i['section_item_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture_left" title="<?php echo $i['image']['file_title'];?>"></a>
						<a href="g_library.php?group_id=<?php echo $i['section_item_id'];?>&amp;page_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
						<span class="txt_footer"><?php echo dots('120', $i['library_synopsis']);?></span><br />
					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_library'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_publish_forum'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($publish_forum)) {
				foreach($publish_forum as $key => $i):
				?>
				 <tr>
					<td>
						<a href="g_subject.php?group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture_left" title="<?php echo $i['image']['file_title'];?>"></a>
						<a href="g_forum_subject.php?group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<span class="txt_footer"><?php echo dots('120', $i['subject_body']);?></span><br />
					</td>
					<td align="right" valign="top">
						<span class="txt_footer"><?php echo $i['total_replies'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_forum'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['hdr_publish_blog_item'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				?>
				 <tr>
					<td valign="top">
						<a href="my_blog.php?blog_id=<?php echo $i['blog_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture_left" title="<?php echo $i['image']['file_title'];?>"></a>
						<a href="my_blog.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['blog_synopsis'];?></span><br />
					</td>
					<td align="right" valign="top" nowrap>
						<span class="txt_footer"><?php echo $i['blog_create_datetime'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_blogs'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>


		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_poll_participation'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($poll_participation)) {
				foreach($poll_participation as $key => $i):
				?>
				 <tr>
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td valign="top">
						<?php echo $i['poll_question'];?><br />
						<span class="txt_footer"><?php echo $i['option_body'];?></span><br />
					</td>
					<td align="right" valign="top">
						<span class="txt_footer"><?php echo $i['answer_create_datetime'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_poll_participation'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right" colspan="2">
						<?php echo $lang['hdr_publish_shouts'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($publish_shouts)) {
				foreach($publish_shouts as $key => $i):
				?>
			    <tr valign="top">
					<td width="3" valign="top">
						<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
					</td>
					<td>
						<?php echo $i['shoutbox_create_datetime'];?>: <?php echo $i['shoutbox_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td colspan="2">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="2">
						<?php echo $lang['err_no_shouts'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
		</td>
	</tr>
</table>
